@@ -7,10 +7,10 @@
 
 ;; This file is part of GNU Emacs.
 
-;; GNU Emacs is free software; you can redistribute it and/or modify
+;; GNU Emacs is free software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; the Free Software Foundation, either version 3 of the License, or
+;; (at your option) any later version.
 
 ;; GNU Emacs is distributed in the hope that it will be useful,
 ;; but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +18,7 @@
 ;; GNU General Public License for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with GNU Emacs; see the file COPYING.  If not, see
-;; <http://www.gnu.org/licenses/>.
+;; along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -153,11 +152,12 @@ this is the function `temp-directory'."
 (defsubst tramp-compat-make-temp-file (filename)
   "Create a temporary file (compat function).
 Add the extension of FILENAME, if existing."
-  (let ((prefix (expand-file-name
-		 (symbol-value 'tramp-temp-name-prefix)
-		 (tramp-compat-temporary-file-directory)))
-	(extension (file-name-extension filename t))
-	result)
+  (let* (file-name-handler-alist
+	 (prefix (expand-file-name
+		  (symbol-value 'tramp-temp-name-prefix)
+		  (tramp-compat-temporary-file-directory)))
+	 (extension (file-name-extension filename t))
+	 result)
     (condition-case nil
 	(setq result
 	      (funcall (symbol-function 'make-temp-file) prefix nil extension))
